@@ -1,5 +1,5 @@
 package experimentals;
-our $VERSION = '0.016';
+our $VERSION = '0.017';
 
 use 5.010;
 use strict;
@@ -81,7 +81,7 @@ experimentals - Experimental features made even easier
 
 =head1 VERSION
 
-This document describes experimentals version 0.016
+This document describes experimentals version 0.017
 
 
 =head1 SYNOPSIS
@@ -164,8 +164,8 @@ an "experimental" warning. From 5.18 onwards, it does.
 
 Similarly, Perl 5.14 added the ability to pass an array reference as the
 first argument of C<push>. But in 5.20, this feature was retconned to
-"experimental" status, and now generates a warning under more recent
-versions of Perl.
+"experimental" status, and started generating a warning. In Perl 5.24
+the feature was removed entirely, and now generates a compile-time error.
 
 This means that, when porting existing code to run under Perl 5.18 or
 later, you may start getting spurious warnings if that code contains any
@@ -222,7 +222,19 @@ Note that, when C<use experimentals -report> is specified
 all other non-fatal compile-time warnings are suppressed,
 and the code itself is only compiled, not executed.
 
-Note too, however, that the module is lexically scoped, so it cannot
+Fatal errors cannot be suppressed, however, so under Perl
+5.24 the report would look like:
+
+    old_code.pl line 10:     Given
+    old_code.pl line 11:     When
+    old_code.pl line 12:     When
+    old_code.pl line 12:     Smartmatch
+    old_code.pl line 13:     The bitwise feature
+    Can't use global $_ in "my" at old_code.pl line 7, near "my $_ "
+    Experimental push on scalar is now forbidden at old_code.pl line 13, near "2;"
+    Execution of old_code.pl aborted due to compilation errors.
+
+Note too that the module is lexically scoped, so it cannot
 report problems inside an C<eval $STRING> call...unless the
 S<C<use experimentals -report>> itself is inside the string as well.
 In that case, obviously, the code I<will> be executed, since the C<eval>
